@@ -10,7 +10,7 @@ from virtualenv.info import IS_WIN, fs_is_case_sensitive, fs_supports_symlink
 CURRENT = PythonInfo.current()
 
 
-def test_discover_empty_folder(tmp_path, monkeypatch, session_app_data):
+def test_discover_empty_folder(tmp_path, session_app_data):
     with pytest.raises(RuntimeError):
         CURRENT.discover_exe(session_app_data, prefix=str(tmp_path))
 
@@ -24,7 +24,7 @@ BASE = (CURRENT.install_path("scripts"), ".")
 @pytest.mark.parametrize("arch", [CURRENT.architecture, ""])
 @pytest.mark.parametrize("version", [".".join(str(i) for i in CURRENT.version_info[0:i]) for i in range(3, 0, -1)])
 @pytest.mark.parametrize("impl", [CURRENT.implementation, "python"])
-def test_discover_ok(tmp_path, monkeypatch, suffix, impl, version, arch, into, caplog, session_app_data):
+def test_discover_ok(tmp_path, suffix, impl, version, arch, into, caplog, session_app_data):
     caplog.set_level(logging.DEBUG)
     folder = tmp_path / into
     folder.mkdir(parents=True, exist_ok=True)
